﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO;
using System.Collections;

namespace Prohlizec
{
    public partial class FileTree : Form
    {
        public FileTree()
        {
            InitializeComponent();
            InitializeDirTree(Program.RootDir);

            this.listViewFiles.MouseDoubleClick += new MouseEventHandler(listViewFiles_MouseDoubleClick);
            this.listViewFiles.KeyUp += new KeyEventHandler(listViewFiles_KeyUp);
            this.listViewFiles.KeyUp += new KeyEventHandler(FileTree_KeyUp);
            this.treeDirs.KeyUp += new KeyEventHandler(FileTree_KeyUp);
            this.KeyUp += new KeyEventHandler(FileTree_KeyUp);
            this.splitContainer1.GotFocus += new EventHandler(ResetFocus);
            this.splitContainerVertical.GotFocus += new EventHandler(ResetFocus);
            this.splitContainer1.Panel1.GotFocus += new EventHandler(ResetFocus);
            this.splitContainer1.Panel2.GotFocus += new EventHandler(ResetFocus);
            this.splitContainerVertical.Panel1.GotFocus += new EventHandler(ResetFocus);
            this.splitContainerVertical.Panel1.GotFocus += new EventHandler(ResetFocus);

            if (Program.SelectedFile != null)
            {
                ImagePreview lPreview = new ImagePreview(Program.SelectedFile);
                if (lPreview.ShowDialog() == DialogResult.Abort)
                    this.Close();
            }
        }

        void ResetFocus(object sender, EventArgs e)
        {
            this.Focus();
        }

        void FileTree_KeyUp(object sender, KeyEventArgs e)
        {
            if (e.KeyCode == Keys.Escape)
                this.Close();
        }

        void listViewFiles_KeyUp(object sender, KeyEventArgs e)
        {
            if (e.KeyCode == Keys.Enter)
                listViewFiles_MouseDoubleClick(null, null);
        }

        void listViewFiles_MouseDoubleClick(object sender, MouseEventArgs e)
        {
            if (this.listViewFiles.SelectedItems.Count < 1)
                return;
            
            ImagePreview lPreview = new ImagePreview(this.listViewFiles.SelectedItems[0].Name);
            if (lPreview.ShowDialog() == DialogResult.Abort)
                this.Close();
        }

        private void InitializeDirTree(string rootDir)
        {
            this.treeDirs.BeforeExpand += new TreeViewCancelEventHandler(treeDirs_BeforeExpand);
            this.treeDirs.AfterSelect += new TreeViewEventHandler(treeDirs_AfterSelect);

            this.treeDirs.Nodes.Clear();
            TreeNode tnInserted = this.treeDirs.Nodes.Add(rootDir, Program.GetPureDirName(rootDir));
            LoadDirNodes(rootDir, tnInserted.Nodes);
        }

        void treeDirs_AfterSelect(object sender, TreeViewEventArgs e)
        {
            Program.SelectedDir = this.treeDirs.SelectedNode.Name;

            progressBar.Visible = true;
            ShowFiles();
            progressBar.Visible = false;
        }

        void ShowFiles()
        {
            string[] sFiles;
            int iImageIndex = 0;
            ArrayList lListViewItems = new ArrayList();

            this.listViewFiles.Items.Clear();
            this.listViewFiles.LargeImageList = new ImageList();
            this.listViewFiles.LargeImageList.Images.Clear();
            
            sFiles = Directory.GetFiles(Program.SelectedDir, "*.jpg", SearchOption.TopDirectoryOnly);
            progressBar.Maximum = sFiles.Length;
            progressBar.Value = 0;
            foreach (string sFile in sFiles)
            {
                this.listViewFiles.LargeImageList.Images.Add(iImageIndex.ToString(), Image.FromFile(sFile));
                ListViewItem lvi = new ListViewItem(Program.GetPureFileName(sFile), iImageIndex.ToString());
                lvi.Name = sFile;
                lListViewItems.Add(lvi);
                iImageIndex++;
                progressBar.Increment(1);
            }

            sFiles = Directory.GetFiles(Program.SelectedDir, "*.jpeg", SearchOption.TopDirectoryOnly);
            progressBar.Maximum = sFiles.Length;
            progressBar.Value = 0;
            foreach (string sFile in sFiles)
            {
                this.listViewFiles.LargeImageList.Images.Add(iImageIndex.ToString(), Image.FromFile(sFile));
                ListViewItem lvi = new ListViewItem(Program.GetPureFileName(sFile), iImageIndex.ToString());
                lvi.Name = sFile;
                lListViewItems.Add(lvi);
                iImageIndex++;
                progressBar.Increment(1);
            }

            this.listViewFiles.Items.AddRange((ListViewItem[])lListViewItems.ToArray(typeof(ListViewItem)));
        }

        void treeDirs_BeforeExpand(object sender, TreeViewCancelEventArgs e)
        {
            foreach (TreeNode lNode in e.Node.Nodes)
            {
                lNode.Nodes.Clear();
                LoadDirNodes(lNode.Name, lNode.Nodes);
            }
        }

        private void LoadDirNodes(string dir, TreeNodeCollection parentNode)
        {
            string[] sDirs = null;

            try
            {
                sDirs = Directory.GetDirectories(dir, "*", SearchOption.TopDirectoryOnly);
            }
            catch
            {
            }

            if (sDirs == null)
                return;

            foreach (string sDir in sDirs)
            {
                TreeNode tnInserted = parentNode.Add(sDir, Program.GetPureDirName(sDir));
            }
        }
    }
}
