﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO;

namespace Prohlizec
{
    public partial class ImagePreview : Form
    {
        private string sFile;
        private string[] sFiles;
        private int iIndex, iMax;
        
        public ImagePreview(string imageFile)
        {
            InitializeComponent();

            string sDir = Program.GetDirFromFile(imageFile);
            string[] sJPGFiles = Directory.GetFiles(sDir, "*.jpg", SearchOption.TopDirectoryOnly);
            string[] sJPEGFiles = Directory.GetFiles(sDir, "*.jpeg", SearchOption.TopDirectoryOnly);
            sFiles = new string[sJPGFiles.Length + sJPEGFiles.Length];
            int i;

            for (i = 0; i < sJPGFiles.Length; i++)
            {
                sFiles[i] = sJPGFiles[i];
                if (sFiles[i] == imageFile)
                    iIndex = i + 1;
            }

            for (i = 0; i < sJPEGFiles.Length; i++)
            {
                sFiles[i + sJPGFiles.Length] = sJPEGFiles[i];
                if (sFiles[i] == imageFile)
                    iIndex = i + 1;
            }

            iMax = sFiles.Length;
            sFile = imageFile;

            this.pictureBox.Image = Image.FromFile(sFile);
            this.WindowState = FormWindowState.Maximized;
            this.Text = "Picture Browser [" + iIndex + " / " + iMax + "] - " + sFile;
            this.KeyUp += new KeyEventHandler(ImagePreview_KeyUp);
            this.pictureBox.MouseDoubleClick += new MouseEventHandler(pictureBox_MouseDoubleClick);
            this.Focus();

            this.splitContainer1.GotFocus += new EventHandler(ResetFocus);
            this.splitContainer1.Panel1.GotFocus += new EventHandler(ResetFocus);
            this.splitContainer1.Panel2.GotFocus += new EventHandler(ResetFocus);
            this.pictureBox.GotFocus += new EventHandler(ResetFocus);
            this.SizeChanged += new EventHandler(ResetFocus);
        }

        void pictureBox_MouseDoubleClick(object sender, MouseEventArgs e)
        {
            this.DialogResult = DialogResult.OK;
            this.Close();
        }

        void ResetFocus(object sender, EventArgs e)
        {
            this.Focus();
        }

        void ImagePreview_KeyUp(object sender, KeyEventArgs e)
        {
            switch (e.KeyCode)
            {
                case Keys.Home:
                    iIndex = 1;
                    sFile = sFiles[iIndex - 1];
                    this.pictureBox.Image = Image.FromFile(sFile);
                    this.Text = "Picture Browser [" + iIndex + " / " + iMax + "] - " + sFile;
                    break;
                case Keys.End:
                    iIndex = iMax;
                    sFile = sFiles[iIndex - 1];
                    this.pictureBox.Image = Image.FromFile(sFile);
                    this.Text = "Picture Browser [" + iIndex + " / " + iMax + "] - " + sFile;
                    break;
                case Keys.PageUp:
                    if (iIndex > 1)
                    {
                        iIndex--;
                        sFile = sFiles[iIndex - 1];
                        this.pictureBox.Image = Image.FromFile(sFile);
                        this.Text = "Picture Browser [" + iIndex + " / " + iMax + "] - " + sFile;
                    }
                    break;
                case Keys.PageDown:
                    if (iIndex < iMax)
                    {
                        iIndex++;
                        sFile = sFiles[iIndex - 1];
                        this.pictureBox.Image = Image.FromFile(sFile);
                        this.Text = "Picture Browser [" + iIndex + " / " + iMax + "] - " + sFile;
                    }
                    break;
                case Keys.Enter:
                    this.DialogResult = DialogResult.OK;
                    this.Close();
                    break;
                case Keys.Escape:
                    this.DialogResult = DialogResult.Abort;
                    this.Close();
                    break;
                case Keys.Multiply:
                    this.pictureBox.SizeMode = PictureBoxSizeMode.CenterImage;
                    break;
                case Keys.Divide:
                    this.pictureBox.SizeMode = PictureBoxSizeMode.Zoom;
                    break;
                case Keys.H:
                    this.pictureBox.Image.RotateFlip(RotateFlipType.RotateNoneFlipX);
                    this.pictureBox.Refresh();
                    break;
                case Keys.V:
                    this.pictureBox.Image.RotateFlip(RotateFlipType.RotateNoneFlipY);
                    this.pictureBox.Refresh();
                    break;
                case Keys.L:
                    this.pictureBox.Image.RotateFlip(RotateFlipType.Rotate270FlipNone);
                    this.pictureBox.Refresh();
                    break;
                case Keys.R:
                    this.pictureBox.Image.RotateFlip(RotateFlipType.Rotate90FlipNone);
                    this.pictureBox.Refresh();
                    break;
                default: break;
            }
        }
    }
}
